@@ -8,8 +8,7 @@
 #include <gnome.h>
 
 #include "callbacks.h"
-#include "interface.h"
-#include "support.h"
+#include <schedwi_interface.h>
 
 
 #include <hosts_cb.h>
@@ -57,9 +56,7 @@ void
 on_about2_activate                     (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-	GtkWidget *about;
-	about = create_about1 ();
-	gtk_widget_show (about);
+	schedwi_main_about ();
 }
 
 
