@@ -1,27 +1,27 @@
 /* Schedwi
    Copyright (C) 2007 Herve Quatremain
-     
-   This program is free software; you can redistribute it and/or modify
+
+   This file is part of Schedwi.
+
+   Schedwi is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
-     
-   This program is distributed in the hope that it will be useful,
+
+   Schedwi is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Library General Public License for more details.
-     
+   GNU General Public License for more details.
+
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* child_job.c -- Structure to draw a job/jobset on a GnomeCanvas */
 
 #include <schedwi.h>
 
-#include "support.h"
-#include "interface.h"
+#include <schedwi_interface.h>
 
 #include <math.h>
 
@@ -329,6 +329,9 @@ child_job_init (child_job_t *ptr,
 	ptr->start_time = 0;
 	ptr->start_limit = 0;
 	ptr->max_duration = 0;
+	ptr->retries = 0;
+	ptr->retry_num = 0;
+	ptr->retries_interval = 0;
 	ptr->status_message = NULL;
 	return TRUE;
 }
@@ -1424,15 +1427,15 @@ view_popup_menu_job (GdkEventButton *event, child_job_t *ptr)
 static void
 child_job_tooltips_start (child_job_t *ptr)
 {
-	char *label[5];
-	char *value[5];
+	char *label[6];
+	char *value[6];
 	char *title, *s1, *s2, *s3;
-	gchar *s4;
+	gchar *s4, *s5;
 	unsigned int i;
 
 	i = 0;
 	s1 = s2 = s3 = NULL;
-	s4 = NULL;
+	s4 = s5 = NULL;
 	switch (ptr->state) {
 		case JOB_STATUS_STATE_WAITING:
 			title = job_status_state2str (ptr->state);
@@ -1457,6 +1460,14 @@ child_job_tooltips_start (child_job_t *ptr)
 				value[i++] = s3;
 			}
 
+			if (ptr->retry_num > 0) {
+				label[i] = _("Failed tries:");
+				s4 = g_strdup_printf ("%d/%d",
+					ptr->retry_num,
+					ptr->retries + 1);
+				value[i++] = s4;
+			}
+
 			if (	   ptr->status_message != NULL
 				&& (ptr->status_message)[0] != '\0')
 			{
@@ -1506,6 +1517,12 @@ child_job_tooltips_start (child_job_t *ptr)
 				value[i++] = s3;
 			}
 
+			label[i] = _("Try:");
+			s5 = g_strdup_printf ("%d/%d",
+				ptr->retry_num + 1,
+				ptr->retries + 1);
+			value[i++] = s5;
+
 			if (	   ptr->status_message != NULL
 				&& (ptr->status_message)[0] != '\0')
 			{
@@ -1548,7 +1565,7 @@ child_job_tooltips_start (child_job_t *ptr)
 			title = _("Not planned");
 			break;
 	}
-	while (i < 5) {
+	while (i < 6) {
 		label[i] = NULL;
 		value[i] = NULL;
 		i++;
@@ -1561,7 +1578,8 @@ child_job_tooltips_start (child_job_t *ptr)
 				label[1], value[1],
 				label[2], value[2],
 				label[3], value[3],
-				label[4], value[4]);
+				label[4], value[4],
+				label[5], value[5]);
 	if (s1 != NULL) {
 		free (s1);
 	}
@@ -1572,6 +1590,7 @@ child_job_tooltips_start (child_job_t *ptr)
 		free (s3);
 	}
 	g_free (s4);
+	g_free (s5);
 }
 
 
