@@ -1,27 +1,27 @@
 /* Schedwi
    Copyright (C) 2007 Herve Quatremain
 
-   This program is free software; you can redistribute it and/or modify
+   This file is part of Schedwi.
+
+   Schedwi is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
+   Schedwi is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Library General Public License for more details.
+   GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* main_cb.c -- GUI functions for the main window */
 
 #include <schedwi.h>
 
-#include "support.h"
-#include "interface.h"
+#include <schedwi_interface.h>
 
 #include <math.h>
 
@@ -718,33 +718,46 @@ main_init (GtkWidget *main_window, const gchar *user)
 	user_name = g_strdup (user);
 
 	combo = lookup_widget (main_window, "combobox_main_workload");
+
+	/*
+	 * Clear the first item added in glade for libglade to use
+	 * gtk_combo_box_new_text() instead of gtk_combo_box_new()
+	 */
+	gtk_combo_box_remove_text (GTK_COMBO_BOX (combo), 0);
+
 	workload_init_combo (GTK_COMBO_BOX (combo));
 	spin = lookup_widget (main_window, "spinbutton_main_update_interval");
 	workload_update_interval (GTK_SPIN_BUTTON (spin));
 
+
 	view = lookup_widget (main_window, "treeview_main");
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (view));
 	gtk_tree_store_clear (GTK_TREE_STORE (model));
 	workload_date = (int) workload_get_workload (combo);
 
-	/* Retrieve the jobsets and fill the model */
-	if (retrieve_jobsets_and_fill_model (	GTK_TREE_STORE (model),
-						0, NULL, workload_date) < 0)
-	{
-		gtk_tree_store_clear (GTK_TREE_STORE (model));
-		return FALSE;
-	}
-
-	/* Expand and select the first level */
-	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (view));
-	root_path = gtk_tree_path_new_first ();
-	gtk_tree_view_expand_to_path (GTK_TREE_VIEW (view), root_path);
-	gtk_tree_selection_select_path (select, root_path);
-	gtk_tree_path_free (root_path);
-
 	/* Make the menu and toolbar items sensitive */
 	main_activate ();
 
+	if (workload_date == 0) {
+		main_deactivate_no_workload ();
+	}
+	else {
+		/* Retrieve the jobsets and fill the model */
+		if (retrieve_jobsets_and_fill_model (GTK_TREE_STORE (model),
+						0, NULL, workload_date) < 0)
+		{
+			gtk_tree_store_clear (GTK_TREE_STORE (model));
+			return FALSE;
+		}
+
+		/* Expand and select the first level */
+		select = gtk_tree_view_get_selection (GTK_TREE_VIEW (view));
+		root_path = gtk_tree_path_new_first ();
+		gtk_tree_view_expand_to_path (GTK_TREE_VIEW (view), root_path);
+		gtk_tree_selection_select_path (select, root_path);
+		gtk_tree_path_free (root_path);
+	}
+
 	return TRUE;
 }
 
@@ -987,6 +1000,7 @@ jobset_list_refresh (GtkWidget *w)
 	gdouble saved_scroll_v, saved_scroll_h;
 	int workload_date;
 
+
 	cursor_busy (w);
 
 	view = (GtkTreeView *)lookup_widget (w, "treeview_main");
@@ -1001,6 +1015,26 @@ jobset_list_refresh (GtkWidget *w)
 		saved_selection = NULL;
 	}
 
+	/* Retrieve the workload date */
+	workload_date = (int) workload_get_workload (w);
+
+	/* No workload available */
+	if (workload_date == 0) {
+		jobset_dump_saved_selection (saved_selection);
+		copy_paste_clear ();
+		if (jobset != NULL) {
+			destroy_jobset_item (jobset);
+			g_object_set_data (G_OBJECT (canvas), "jobset", NULL);
+		}
+		model = gtk_tree_view_get_model (view);
+		gtk_tree_store_clear (GTK_TREE_STORE (model));
+		main_deactivate_no_workload ();
+		cursor_normal (w);
+		return;
+	}
+
+	main_activate ();
+
 	/* Retrieve the current selected jobset in the list */
 	selection = gtk_tree_view_get_selection (view);
 	if (gtk_tree_selection_get_selected (selection, &model, &iter) == TRUE)
@@ -1008,7 +1042,7 @@ jobset_list_refresh (GtkWidget *w)
 		gtk_tree_model_get (model, &iter, 1, &selected_id, -1);
 	}
 	else {
-		selected_id = 0;
+		selected_id = 1;
 	}
 
 	/* Retrieve the expanded rows */
@@ -1019,8 +1053,6 @@ jobset_list_refresh (GtkWidget *w)
 						&expanded);
 	g_array_sort (expanded.array, compare_guint64);
 
-	/* Retrieve the workload date */
-	workload_date = (int) workload_get_workload (w);
 
 	/* Save the zoom level */
 	saved_zoom = zoom_save (w);
@@ -1032,10 +1064,11 @@ jobset_list_refresh (GtkWidget *w)
 	/* Clear the model */
 	gtk_tree_store_clear (GTK_TREE_STORE (model));
 
+
 	/* Retrieve the jobset list and fill the model */
-	retrieve_jobsets_and_fill_model (	GTK_TREE_STORE (model),
-						selected_id, &ref,
-						workload_date);
+	retrieve_jobsets_and_fill_model (GTK_TREE_STORE (model),
+					selected_id, &ref,
+					workload_date);
 
 	/* Expand the previously expanded items */
 	gtk_tree_model_foreach (model, expand_item_in_array, &expanded);
